@@ -386,6 +386,13 @@ linRegClass <- R6::R6Class(
 
             for (i in seq_along(self$options$blocks))
                 table$addRow(rowKey=i, values=list(model = i))
+
+            table$setNote(
+                "n",
+                jmvcore::format(
+                    .("Models estimated using sample size of N={n}"), n="..."
+                )
+            )
         },
         .initModelCompTable = function() {
             table <- self$results$modelComp
@@ -668,6 +675,14 @@ linRegClass <- R6::R6Class(
 
                 table$setRow(rowNo=i, values = row)
             }
+
+            table$setNote(
+                "n",
+                jmvcore::format(
+                    "Models estimated using sample size of N={n}",
+                    n=length(models[[1]]$fitted.values)
+                )
+            )
         },
         .populateModelCompTable = function() {
             table <- self$results$modelComp
