@@ -280,6 +280,13 @@ logRegMultiClass <- R6::R6Class(
 
             for (i in seq_along(self$options$blocks))
                 table$addRow(rowKey=i, values=list(model = i))
+
+            table$setNote(
+                "n",
+                jmvcore::format(
+                    .("Models estimated using sample size of N={n}"), n="..."
+                )
+            )
         },
         .initModelCompTable = function() {
             table <- self$results$modelComp
@@ -526,6 +533,14 @@ logRegMultiClass <- R6::R6Class(
 
                 table$setRow(rowNo=i, values = row)
             }
+
+            table$setNote(
+                "n",
+                jmvcore::format(
+                    "Models estimated using sample size of N={n}",
+                    n=nrow(model.frame(self$models[[1]]))
+                )
+            )
         },
         .populateModelCompTable = function() {
             if (length(self$nModels) <= 1)
